// Dear emacs, this is -*- c++ -*-
// $Id$
#ifndef PFRAME_TESTCYCLE_H
#define PFRAME_TESTCYCLE_H

// STL include(s):
#include <vector>

// ROOT include(s):
#include <TH1.h>

// Local include(s):
#include "CycleBase.h"

/**
 * @short Simple test cycle
 *
 *        This test cycle was designed to run on the "SFrame test file"
 *        (/afs/cern.ch/atlas/maxidisk/d181/SFrame/StacoTau1p3p__dcache-pythiazeeSUSYView_1.AAN.root).
 *        It connects to a few variables in the truth tree and creates a
 *        histogram with the true electron pT distribution.
 */
class TestCycle : public pf::CycleBase {

public:
   TestCycle();
   ~TestCycle();

protected:
   //
   // Functions inherited from pf::CycleBase:
   //
   virtual void BeginInputData();
   virtual void BeginInputFile();
   virtual void ExecuteEvent( Double_t weight );

private:
   //
   // Input variables:
   //
   Int_t m_runNumber;
   Int_t m_eventNumber;
   Int_t                  m_tr_El_N;
   std::vector< double >* m_tr_El_p_T;
   Int_t                  m_rec_El_N;
   std::vector< double >* m_rec_El_p_T;

   //
   // Output variables:
   //
   Double_t              m_o_eventWeight;
   std::vector< double > m_o_El_p_T;

   //
   // Output histograms:
   //
   TH1D* m_tr_El_p_T_hist;
   TH1D* m_rec_El_p_T_hist;

   ClassDef( TestCycle, 0 );

}; // class TestCycle

#endif // PFRAME_TESTCYCLE_H
