
// STL include(s):
#include <iostream>

// ROOT include(s):
#include <TProof.h>
#include <TChain.h>
#include <TDSet.h>
#include <TSystem.h>
#include <TList.h>
#include <TFile.h>

void proof_test() {

   //
   // Connect to the PROOF server:
   //
   TProof* proof = TProof::Open( "krasznaa@pcatlas1.atomki.hu" );
   //   proof->SetLogLevel( 0 );

   //
   // Set up the input data:
   //
   TChain chain( "Truth0" );
   /*
   chain.Add( "/Users/attila/ATLAS/sw/projects/pframe/"
              "StacoTau1p3p__dcache-pythiazeeSUSYView_1.AAN.root" );
   */
   chain.Add( "/home/krasznaa/"
              "StacoTau1p3p__dcache-pythiazeeSUSYView_1.AAN.root" );
   TDSet set( chain );

   //
   // Load all the libraries for the PFrame library locally:
   //
   if( gSystem->Load( "libTree" ) == -1 ) {
      std::cout << "Couldn't load the Tree library!" << std::endl;
      return;
   } else {
      std::cout << "Loaded the Tree library" << std::endl;
   }

   if( gSystem->Load( "libHist" ) == -1 ) {
      std::cout << "Couldn't load the Hist library!" << std::endl;
      return;
   } else {
      std::cout << "Loaded the Hist library" << std::endl;
   }

   //
   // Load PFrame itself:
   //
   if( gSystem->Load( "../libPFrame" ) == -1 ) {
      std::cout << "Couldn't load the PFrame library!" << std::endl;
      return;
   } else {
      std::cout << "Loaded the PFrame library" << std::endl;
   }

   //
   // Upload the PFrame package to the worker nodes:
   //
   if( proof->UploadPackage( "../PFrame.par" ) == -1 ) {
      std::cout << "Couldn't upload PFrame.par to nodes!" << std::endl;
      return;
   } else {
      std::cout << "Uploaded PFrame.par to all nodes" << std::endl;
   }

   //
   // Compile the PFrame package on the worker nodes:
   //
   if( proof->EnablePackage( "PFrame", kTRUE ) == -1 ) {
      std::cout << "Couldn't enable (compile) PFrame on worker nodes!"
                << std::endl;
      return;
   } else {
      std::cout << "Enabled PFrame on the worker nodes" << std::endl;
   }

   //
   // Run the TestCycle selector:
   //
   proof->Process( &set, "TestCycle", "", 100 );

   //
   // Draw the output histogram. The object with index "0" is an object
   // describing the status of the PROOF job. Could be interesting to use
   // it later on.
   //
   /*
   TList* output = proof->GetOutputList();
   TH1* hist = dynamic_cast< TH1* >( output->At( 1 ) );
   if( hist ) {
      hist->Draw();
   }
   */

   //
   // Write all the created objects into an output file:
   //
   TFile output_file( "proof_test.root", "RECREATE" );
   output_file.cd();

   TList* outputs = proof->GetOutputList();
   for( Int_t i = 0; i < outputs->GetSize(); ++i ) {
      outputs->At( i )->Write();
   }

   output_file.Close();

   return;

}
