// $Id$

// STL include(s):
#include <iostream>

// Local include(s):
#include "../include/TestCycle.h"

ClassImp( TestCycle );

TestCycle::TestCycle()
   : pf::CycleBase() {

   m_tr_El_p_T_hist  = 0;
   m_rec_El_p_T_hist = 0;

}

TestCycle::~TestCycle() {

}

void TestCycle::BeginInputData() {

   std::cout << "In TestCycle::BeginInputData" << std::endl;

   //
   // Book the output histogram:
   //
   m_tr_El_p_T_hist = Book( TH1D( "tr_El_p_T", "True Electron p_{T}", 100, 0.0,
                                  200000.0 ) );
   m_rec_El_p_T_hist = Book( TH1D( "rec_El_p_T", "Reco. Electron p_{T}",
                                   100, 0.0, 200000.0 ) );

   //
   // Connect the output variables:
   //
   DeclareVariable( m_o_eventWeight, "eventWeight" );
   DeclareVariable( m_o_El_p_T, "El_p_T" );

   return;

}

void TestCycle::BeginInputFile() {

   std::cout << "In TestCycle::BeginInputFile" << std::endl;

   //
   // Connect the input variables:
   //
   ConnectVariable( "Truth0", "runNumber", m_runNumber );
   ConnectVariable( "Truth0", "eventNumber", m_eventNumber );
   ConnectVariable( "Truth0", "El_N", m_tr_El_N );
   ConnectVariable( "Truth0", "El_p_T", m_tr_El_p_T );
   ConnectVariable( "FullRec0", "El_N", m_rec_El_N );
   ConnectVariable( "FullRec0", "El_p_T", m_rec_El_p_T );

   return;

}

void TestCycle::ExecuteEvent( Double_t weight ) {

   /*
   std::cout << "In TestCycle::ExecuteEvent" << std::endl;

   std::cout << "Run number   = " << m_runNumber << std::endl;
   std::cout << "Event number = " << m_eventNumber << std::endl;

   std::cout << "El number    = " << m_El_p_T->size() << std::endl;
   */

   //
   // Clear the output vector(s):
   //
   m_o_El_p_T.clear();

   //
   // Fill the output objects:
   //
   m_o_eventWeight = weight;
   for( Int_t i = 0; i < m_tr_El_N; ++i ) {
      m_tr_El_p_T_hist->Fill( m_tr_El_p_T->at( i ), weight );
   }
   for( Int_t i = 0; i < m_rec_El_N; ++i ) {
      m_rec_El_p_T_hist->Fill( m_rec_El_p_T->at( i ), weight );
      m_o_El_p_T.push_back( m_rec_El_p_T->at( i ) );
   }

   return;

}
